# Qtica

Qtica is a Python library that provides a lightweight API around native PySide6, allowing for lightning-fast GUI prototyping using modern declarative UI techniques entirely within Python. Qtica is available under the GPLv3 license.

# It's ready to use wait for the doc!
